blohg
~~~~~

blohg is a simple and easy to use blog engine, that uses the Mercurial
SCM as backend, to store the content of the posts and pages.

blohg doesn't have a nice control panel nor WYSIWIG editors. All the
content is written using any text editor and reStructuredText with some
custom directives.


- Home Page: http://blohg.org/
- Documentation: http://docs.blohg.org/
- Mailing List: blohg@librelist.com
